Pixie.Backend.ETS.Namespaces
This process manages the generation and removal of unique identifiers. These are mostly used for client ID's, but can be other stuff too.
Summary
| generate_namespace(length) | |
| release_namespace(namespace) | |
| start_link() |
This process manages the generation and removal of unique identifiers. These are mostly used for client ID's, but can be other stuff too.
| generate_namespace(length) | |
| release_namespace(namespace) | |
| start_link() |