Pixie.Message
This module handles dispatch of incoming messages to their corresponding message structs.
Summary
Functions
Take message (the map output from JSON decoding) and apply the following transformations:
This module handles dispatch of incoming messages to their corresponding message structs.
Take message (the map output from JSON decoding) and apply the following transformations: