Pixie.Message.Unsubscribe
Convert an incoming unsubscription request into a struct.
Request
MUST include: * channel
* clientId
* subscription
MAY include: * ext
* id
This struct contains the following keys:
:channelalways"/meta/unsubscribe".:subscriptionthe channel the user wishes to subscribe to.:client_idthe client ID generated by the server during handshake.:extan arbitrary map of data the client sent for use in extensions (usually authentication information, etc). Optional.:ida message ID generated by the client. Optional.
Summary
| init(message) | Convert the incoming message into a |
Functions
Convert the incoming message into a Pixie.Message.Unsubscribe by copying only those fields we care about.