Pixie.Message
This module handles dispatch of incoming messages to their corresponding message structs.
Summary
| init(message) | Take |
Functions
Take message (the map output from JSON decoding) and apply the following transformations:
- Convert all keys to lower case.
- Convert all keys to atoms.
Then dispatch to the correct message module, based on message type.